summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
-rwxr-xr-xchrome/test/debugger/debugger_unittests.py17
-rw-r--r--chrome/test/debugger/test_protocol.js8
-rw-r--r--tools/purify/chrome_tests.py5
-rwxr-xr-xtools/traceline/traceline/scripts/crit_sec.js2
-rwxr-xr-xtools/traceline/traceline/scripts/heap.js2
5 files changed, 16 insertions, 18 deletions
diff --git a/chrome/test/debugger/test_protocol.js b/chrome/test/debugger/test_protocol.js
index 7751677..9ed7ba6 100644
--- a/chrome/test/debugger/test_protocol.js
+++ b/chrome/test/debugger/test_protocol.js
@@ -5,10 +5,10 @@
* @fileoverview Unit tests for testing debugger protocol betweeen front-end JS
* and back-end.
* Run with the following command line:
- * v8_shell_sample.exe --allow-natives-syntax --expose-debug-as debugContext
- * chrome/browser/resources/shell.js
- * v8/tests/mjsunit.js
- * chrome/test/debugger/test_protocol.js
+ * v8_shell.exe --allow-natives-syntax --expose-debug-as debugContext
+ * chrome/browser/resources/shell.js
+ * v8/tests/mjsunit.js
+ * chrome/test/debugger/test_protocol.js
*/
// This test is currently disabled. Please see:
diff --git a/tools/purify/chrome_tests.py b/tools/purify/chrome_tests.py
index b6c095a..76bb051 100644
--- a/tools/purify/chrome_tests.py
+++ b/tools/purify/chrome_tests.py
@@ -124,7 +124,7 @@ class ChromeTests:
self._data_dir = os.path.join(module_dir, "test", "data", "purify")
else:
self._data_dir = os.path.join(module_dir, "data", "purify")
-
+
cmd = list(self._command_preamble)
cmd.append("--data_dir=%s" % self._data_dir)
cmd.append("--report_dir=%s" % self._report_dir)
@@ -344,7 +344,7 @@ class ChromeTests:
multi=True)
def TestV8(self):
- shell = "v8_shell_sample.exe"
+ shell = "v8_shell.exe"
# We need to compute _build_dir early to in order to pass in the
# shell path as an argument to the test script.
self.ComputeBuildDir("chrome", shell)
@@ -402,4 +402,3 @@ def _main(argv):
if __name__ == "__main__":
ret = _main(sys.argv)
sys.exit(ret)
-
diff --git a/tools/traceline/traceline/scripts/crit_sec.js b/tools/traceline/traceline/scripts/crit_sec.js
index 018309a..906bba1 100755
--- a/tools/traceline/traceline/scripts/crit_sec.js
+++ b/tools/traceline/traceline/scripts/crit_sec.js
@@ -2,7 +2,7 @@
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
-// You should run this with v8, like v8_shell_sample alloc.js datafile.json
+// You should run this with v8, like v8_shell alloc.js datafile.json
function toHex(num) {
var str = "";
diff --git a/tools/traceline/traceline/scripts/heap.js b/tools/traceline/traceline/scripts/heap.js
index e8b57a7..9025ac3 100755
--- a/tools/traceline/traceline/scripts/heap.js
+++ b/tools/traceline/traceline/scripts/heap.js
@@ -2,7 +2,7 @@
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
-// You should run this with v8, like v8_shell_sample alloc.js datafile.json
+// You should run this with v8, like v8_shell alloc.js datafile.json
function toHex(num) {
var str = "";
diff --git a/chrome/test/debugger/debugger_unittests.py b/chrome/test/debugger/debugger_unittests.py
index 3aa2ab5..350fd4c 100755
--- a/chrome/test/debugger/debugger_unittests.py
+++ b/chrome/test/debugger/debugger_unittests.py
@@ -14,22 +14,21 @@ import google.path_utils
import google.process_utils
def RunTests(build_dir=None):
- '''This is just a simple wrapper for running the test through v8_shell_sample.
- Since v8_shell_sample always returns 0 whether the test passes or fails,
+ '''This is just a simple wrapper for running the test through v8_shell.
+ Since v8_shell always returns 0 whether the test passes or fails,
buildbot looks at stdout to test for failure.
'''
script_dir = google.path_utils.ScriptDir()
chrome_dir = google.path_utils.FindUpward(script_dir, "chrome")
v8_dir = google.path_utils.FindUpward(script_dir, "v8")
if build_dir:
- v8_shell_sample = os.path.join(build_dir, "v8_shell_sample.exe")
+ v8_shell = os.path.join(build_dir, "v8_shell.exe")
else:
- v8_shell_sample = os.path.join(chrome_dir, "Debug", "v8_shell_sample.exe")
+ v8_shell = os.path.join(chrome_dir, "Debug", "v8_shell.exe")
# look for Debug version first
- if not os.path.isfile(v8_shell_sample):
- v8_shell_sample = os.path.join(chrome_dir, "Release",
- "v8_shell_sample.exe")
- cmd = [v8_shell_sample,
+ if not os.path.isfile(v8_shell):
+ v8_shell = os.path.join(chrome_dir, "Release", "v8_shell.exe")
+ cmd = [v8_shell,
"--allow-natives-syntax",
"--expose-debug-as", "debugContext",
os.path.join(chrome_dir, "browser", "debugger", "resources",
@@ -51,7 +50,7 @@ def RunTests(build_dir=None):
if __name__ == "__main__":
parser = optparse.OptionParser("usage: %prog [--build_dir=dir]")
parser.add_option("", "--build_dir",
- help="directory where v8_shell_sample.exe was built")
+ help="directory where v8_shell.exe was built")
(options, args) = parser.parse_args()
ret = RunTests(options.build_dir)
sys.exit(ret)